{
    "scan": {
        "analyzer-version-clippy": "1.93.1",
        "analyzer-version-cppcheck": "2.20.0",
        "analyzer-version-gcc": "16.0.1",
        "analyzer-version-gcc-analyzer": "16.0.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "diffbase-analyzer-version-clippy": "1.93.1",
        "diffbase-analyzer-version-cppcheck": "2.20.0",
        "diffbase-analyzer-version-gcc": "16.0.1",
        "diffbase-analyzer-version-gcc-analyzer": "16.0.1",
        "diffbase-analyzer-version-shellcheck": "0.11.0",
        "diffbase-analyzer-version-unicontrol": "0.0.2",
        "diffbase-enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "diffbase-exit-code": 0,
        "diffbase-host": "ip-172-16-1-131.us-west-2.compute.internal",
        "diffbase-known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "diffbase-known-false-positives-rpm": "known-false-positives-0.0.0.20260225.110632.gf6ecc5a.main-1.el9.noarch",
        "diffbase-mock-config": "fedora-rawhide-x86_64",
        "diffbase-project-name": "python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1",
        "diffbase-store-results-to": "/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.tar.xz",
        "diffbase-time-created": "2026-03-04 21:21:37",
        "diffbase-time-finished": "2026-03-04 21:23:29",
        "diffbase-tool": "csmock",
        "diffbase-tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'unicontrol,clippy,cppcheck,shellcheck,gcc' '-o' '/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.src.rpm'",
        "diffbase-tool-version": "csmock-3.8.4.20260302.153719.g8203630-1.el9",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-131.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260225.110632.gf6ecc5a.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1",
        "store-results-to": "/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.tar.xz",
        "time-created": "2026-03-04 21:21:37",
        "time-finished": "2026-03-04 21:23:29",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'unicontrol,clippy,cppcheck,shellcheck,gcc' '-o' '/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmpfexc36m_/python-specfile-0.39.1.post1.dev2+g4c435d1-1.20260219071134665114.main.2.g4c435d1.src.rpm'",
        "tool-version": "csmock-3.8.4.20260302.153719.g8203630-1.el9"
    },
    "defects": []
}
